# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/bytetype',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/bytetype',
                'lib_path': 'bytetype'},
  'syms': { 'bytetype.bytes': { 'bytetype.bytes.Bytes': ('bytes.html#bytes', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__add__': ('bytes.html#bytes.__add__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__eq__': ('bytes.html#bytes.__eq__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__ge__': ('bytes.html#bytes.__ge__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__gt__': ('bytes.html#bytes.__gt__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__le__': ('bytes.html#bytes.__le__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__lt__': ('bytes.html#bytes.__lt__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__mul__': ('bytes.html#bytes.__mul__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__ne__': ('bytes.html#bytes.__ne__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__post_init__': ('bytes.html#bytes.__post_init__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__repr__': ('bytes.html#bytes.__repr__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__sub__': ('bytes.html#bytes.__sub__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.__truediv__': ('bytes.html#bytes.__truediv__', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.from_dir': ('bytes.html#bytes.from_dir', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.from_file': ('bytes.html#bytes.from_file', 'bytetype/bytes.py'),
                                'bytetype.bytes.Bytes.to_bytes': ('bytes.html#bytes.to_bytes', 'bytetype/bytes.py')},
            'bytetype.core': { 'bytetype.core.Bytes': ('core.html#bytes', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__add__': ('core.html#bytes.__add__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__eq__': ('core.html#bytes.__eq__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__ge__': ('core.html#bytes.__ge__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__gt__': ('core.html#bytes.__gt__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__le__': ('core.html#bytes.__le__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__lt__': ('core.html#bytes.__lt__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__mul__': ('core.html#bytes.__mul__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__ne__': ('core.html#bytes.__ne__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__post_init__': ('core.html#bytes.__post_init__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__repr__': ('core.html#bytes.__repr__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__sub__': ('core.html#bytes.__sub__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.__truediv__': ('core.html#bytes.__truediv__', 'bytetype/core.py'),
                               'bytetype.core.Bytes.from_dir': ('core.html#bytes.from_dir', 'bytetype/core.py'),
                               'bytetype.core.Bytes.from_file': ('core.html#bytes.from_file', 'bytetype/core.py'),
                               'bytetype.core.Bytes.to_bytes': ('core.html#bytes.to_bytes', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit': ('core.html#bytesunit', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.calc_idx': ('core.html#bytesunit.calc_idx', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.calc_size': ('core.html#bytesunit.calc_size', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.from_bytes': ('core.html#bytesunit.from_bytes', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.keys': ('core.html#bytesunit.keys', 'bytetype/core.py'),
                               'bytetype.core.BytesUnit.unit': ('core.html#bytesunit.unit', 'bytetype/core.py'),
                               'bytetype.core.bytes_idx': ('core.html#bytes_idx', 'bytetype/core.py'),
                               'bytetype.core.bytes_to_size': ('core.html#bytes_to_size', 'bytetype/core.py')},
            'bytetype.enums': { 'bytetype.enums.ByteSize': ('enums.html#bytesize', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit': ('enums.html#bytesunit', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.calc_idx': ('enums.html#bytesunit.calc_idx', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.calc_size': ('enums.html#bytesunit.calc_size', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.from_bytes': ('enums.html#bytesunit.from_bytes', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.keys': ('enums.html#bytesunit.keys', 'bytetype/enums.py'),
                                'bytetype.enums.BytesUnit.unit': ('enums.html#bytesunit.unit', 'bytetype/enums.py')},
            'bytetype.units': {},
            'bytetype.utils': { 'bytetype.utils.bytes_idx': ('utils.html#bytes_idx', 'bytetype/utils.py'),
                                'bytetype.utils.bytes_to_size': ('utils.html#bytes_to_size', 'bytetype/utils.py')}}}
