# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_units.ipynb.

# %% auto 0
__all__ = ['BYTE', 'KILOBYTE', 'MEGABYTE', 'GIGABYTE', 'TERABYTE', 'PETABYTE', 'EXABYTE', 'ZETTABYTE', 'YOTTABYTE']

# %% ../nbs/00_units.ipynb 4
BYTE     : int = 1
KILOBYTE : int = BYTE * 1000
MEGABYTE : int = KILOBYTE ** 2
GIGABYTE : int = KILOBYTE ** 3
TERABYTE : int = KILOBYTE ** 4
PETABYTE : int = KILOBYTE ** 5
EXABYTE  : int = KILOBYTE ** 6
ZETTABYTE: int = KILOBYTE ** 7
YOTTABYTE: int = KILOBYTE ** 8
